@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
+#include <QLabel>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -34,83 +35,16 @@
 using namespace std;
 
 //default constructor
+//Aureport::Aureport(QWidget *parent, const char *name): QWidget(parent, name)
 Aureport::Aureport(QWidget *parent, const char *name): QDialog(parent, name)
 {
-	setCaption(tr("Aureport"));
-
+	//setCaption(tr("Aureport"));
         aureportLabel = new QLabel(tr("Report about"),this);
-        startdayLabel = new QLabel(tr("start-day(1/1/2008)"),this);
+        startdayLabel = new QLabel(tr("start-day(1/1/2009)"),this);
         starttimeLabel = new QLabel(tr("start-time"),this);
         enddayLabel = new QLabel(tr("end-day"),this);
         endtimeLabel = new QLabel(tr("end-time"),this);
 
-        optionButtonGroup = new QButtonGroup(this);
-        optionButtonGroup->resize( 650, 350 );
-        authenticationRadioButton = new QRadioButton(tr("authentication attempts"), optionButtonGroup);
-        authenticationRadioButton->setGeometry( 10, 10, 400, 20 );//-au
-        avcmessagesRadioButton = new QRadioButton(tr("avc messages"), optionButtonGroup);
-        avcmessagesRadioButton->setGeometry( 10, 30, 400, 20 );//-a
-        configRadioButton = new QRadioButton(tr("config changes"), optionButtonGroup);
-        configRadioButton->setGeometry( 10, 50, 400, 20 );//-c
-        cryptoRadioButton = new QRadioButton(tr("crypto events"), optionButtonGroup);
-        cryptoRadioButton->setGeometry( 10, 70, 400, 20 );//-cr
-        eventsRadioButton = new QRadioButton(tr("events"), optionButtonGroup);
-        eventsRadioButton->setGeometry( 10, 90, 400, 20 );//-e
-        filesRadioButton = new QRadioButton(tr("files"), optionButtonGroup);
-        filesRadioButton->setGeometry( 10, 110, 400, 20 );//-f
-        hostsRadioButton = new QRadioButton(tr("hosts"), optionButtonGroup);
-        hostsRadioButton->setGeometry( 10, 130, 400, 20 );//-h
-        loginRadioButton = new QRadioButton(tr("logins"), optionButtonGroup);
-        loginRadioButton->setGeometry( 10, 150, 400, 20 );//-l
-        modificationsRadioButton = new QRadioButton(tr("account modifications"), optionButtonGroup);
-        modificationsRadioButton->setGeometry( 10, 170, 500, 20 );//-m
-        macRadioButton = new QRadioButton(tr("Mandatory Access Control(MAC)events"), optionButtonGroup);
-        macRadioButton->setGeometry( 10, 190, 400, 20 );//-mac
-        pidRadioButton = new QRadioButton(tr("processes"), optionButtonGroup);
-        pidRadioButton->setGeometry( 10, 210, 400, 20 );//-p
-        responseRadioButton = new QRadioButton(tr("responses to anomaly events"), optionButtonGroup);
-        responseRadioButton->setGeometry( 10, 230, 400, 20 );//-r
-        syscallRadioButton = new QRadioButton(tr("syscalls"), optionButtonGroup);
-        syscallRadioButton->setGeometry( 10, 250, 400, 20 );//-s
-        terminalRadioButton = new QRadioButton(tr("terminals"), optionButtonGroup);
-        terminalRadioButton->setGeometry( 10, 270, 400, 20 );//-tm
-        userRadioButton = new QRadioButton(tr("user"), optionButtonGroup);
-        userRadioButton->setGeometry( 10, 290, 400, 20 );//-u
-        executableRadioButton = new QRadioButton(tr("executables"), optionButtonGroup);
-        executableRadioButton->setGeometry( 10, 310, 400, 20 );//-e
-
-        authenticationRadioButton->setChecked(true);
-
-        option2ButtonGroup = new QButtonGroup(this);
-        successFailedRadioButton = new QRadioButton(tr("Both successful and failed events"), option2ButtonGroup);
-        successFailedRadioButton->setGeometry( 10, 10, 400, 20 );//no option
-        successRadioButton = new QRadioButton(tr("Successful events"), option2ButtonGroup);
-        successRadioButton->setGeometry( 10, 30, 400, 20 );//--success
-        failedRadioButton = new QRadioButton(tr("Failed events"), option2ButtonGroup);
-        failedRadioButton->setGeometry( 10, 50, 400, 20 );//--failed
-
-        successFailedRadioButton->setChecked(true);
-
-        summaryCheckBox = new QCheckBox(tr("Run the summary report of the main report"), this);
-        //summaryCheckBox->setGeometry( 10, 10, 400, 20 );//--summary
-
-        interpretCheckBox = new QCheckBox(tr("Interpret numeric entities into text"), this);
-        //interpretCheckBox->setGeometry( 10, 10, 400, 20 );//-i
-/*
-        nodeCheckBox = new QCheckBox(tr(" Select events all nodes for processing in the reports."), this);
-        nodeCheckBox->setGeometry( 10, 10, 400, 20 );//--node
-*/
-
-	aureportButton = new QPushButton(tr("See report"), this);
-	aureportButton->setPaletteBackgroundColor(QColor(250,180,200));
-	connect(aureportButton, SIGNAL(clicked()), this, SLOT(aureport_button_clicked()));
-
-
-	closeButton = new QPushButton(tr("close"), this);
-	//closing process button
-	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
-	closeButton->setDefault(true);
-
         startdayEditLineEdit = new QLineEdit( this );
         startdayEditLineEdit->setText("this-year");
         startdayEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
@@ -127,53 +61,148 @@ Aureport::Aureport(QWidget *parent, const char *name): QDialog(parent, name)
         endtimeEditLineEdit->setText("");
         endtimeEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
 
-	mainLayout = new QVBoxLayout(this);
-	middleLayout = new QVBoxLayout;
-	firstLayout = new QHBoxLayout;
-	secondLayout = new QVBoxLayout;
-	thirdLayout = new QVBoxLayout;
-	tirsharyLayout = new QHBoxLayout;
-	quadroLayout = new QHBoxLayout;
-	fourthLayout = new QHBoxLayout;
-	footLayout = new QHBoxLayout;
-	
-	mainLayout->setMargin(11);
-	secondLayout->addWidget(aureportLabel);
-	secondLayout->addWidget(optionButtonGroup);
-	thirdLayout->addStretch();
-	thirdLayout->addWidget(option2ButtonGroup);
-	thirdLayout->addWidget(summaryCheckBox);
-	thirdLayout->addWidget(interpretCheckBox);
-	tirsharyLayout->addWidget(startdayLabel);
-	tirsharyLayout->addWidget(startdayEditLineEdit);
-	tirsharyLayout->addWidget(starttimeLabel);
-	tirsharyLayout->addWidget(starttimeEditLineEdit);
-	quadroLayout->addWidget(enddayLabel);
-	quadroLayout->addWidget(enddayEditLineEdit);
-	quadroLayout->addWidget(endtimeLabel);
-	quadroLayout->addWidget(endtimeEditLineEdit);
+        summaryCheckBox = new QCheckBox(tr("Run the summary report of the main report"), this);
+        //summaryCheckBox->setGeometry( 10, 10, 400, 20 );//--summary
+
+        interpretCheckBox = new QCheckBox(tr("Interpret numeric entities into text"), this);
+        //interpretCheckBox->setGeometry( 10, 10, 400, 20 );//-i
+        //nodeCheckBox = new QCheckBox(tr(" Select events all nodes for processing in the reports."), this);
+        //nodeCheckBox->setGeometry( 10, 10, 400, 20 );//--node
+
+	//first,create group box 
+        //optionButtonGroupBox = new QGroupBox(this);
+	//optionButtonGroupBox->setFlat(true);
+
+	aureportButton = new QPushButton(tr("See report"), this);
+	aureportButton->setPaletteBackgroundColor(QColor(250,180,200));
+	connect(aureportButton, SIGNAL(clicked()), this, SLOT(aureport_button_clicked()));
+
+	closeButton = new QPushButton(tr("close"), this);
+	//closing process button
+	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
+	closeButton->setDefault(true);
+
 	//thirdLayout->addWidget(nodeCheckBox);
-	fourthLayout->addStretch();
-	fourthLayout->addWidget(aureportButton);
-	fourthLayout->addStretch();
 
-	thirdLayout->addLayout(tirsharyLayout);
-	thirdLayout->addLayout(quadroLayout);
-	firstLayout->addLayout(secondLayout);
-	firstLayout->addLayout(thirdLayout);
-	middleLayout->addLayout(firstLayout);
-	middleLayout->addLayout(fourthLayout);
+	//footLayout->addStretch();
 
-	footLayout->addStretch();
-	footLayout->addWidget(closeButton);
+	//gridLayout = new QGridLayout;
+	mainLayout = new QHBoxLayout;
+	leftLayout = new QVBoxLayout;
+	rightLayout = new QVBoxLayout;
 
-	//mainLayout->addLayout(upperLayout);
-	mainLayout->addLayout(middleLayout);
-	mainLayout->addLayout(footLayout);
+	leftLayout->addWidget(aureportLabel);
+	leftLayout->addWidget(createFirstExclusiveGroup());
+	rightLayout->addWidget(createFirstExclusiveGroup2());
+	rightLayout->addWidget(summaryCheckBox);
+	rightLayout->addWidget(interpretCheckBox);
+	rightLayout->addWidget(startdayLabel);
+	rightLayout->addWidget(startdayEditLineEdit);
+	rightLayout->addWidget(starttimeLabel);
+	rightLayout->addWidget(starttimeEditLineEdit);
+	rightLayout->addWidget(enddayLabel);
+	rightLayout->addWidget(enddayEditLineEdit);
+	rightLayout->addWidget(endtimeLabel);
+	rightLayout->addWidget(endtimeEditLineEdit);
+	rightLayout->addWidget(aureportButton);
+	rightLayout->addWidget(closeButton);
+
+	mainLayout->addLayout(leftLayout);
+	mainLayout->addLayout(rightLayout);
+
+	//setLayout(gridLayout);
+	setLayout(mainLayout);
+	setWindowTitle(tr("Aureport"));
 
 	aureport_process = 0;
+}
+QGroupBox *Aureport::createFirstExclusiveGroup2()
+{
+        optionButtonGroupBox2 = new QGroupBox(tr("successful or failed events"));
+        //option2ButtonGroup = new Q3ButtonGroup(this);
+        //option2ButtonGroup = new QButtonGroup(this);
+        successFailedRadioButton = new QRadioButton(tr("Both successful and failed events"));
+        //successFailedRadioButton->setGeometry( 10, 10, 200, 20 );//no option
+        successRadioButton = new QRadioButton(tr("Successful events"));
+        //successRadioButton->setGeometry( 10, 30, 200, 20 );//--success
+        failedRadioButton = new QRadioButton(tr("Failed events"));
+        //failedRadioButton->setGeometry( 10, 50, 200, 20 );//--failed
 
-	resize(1000,480);
+        successFailedRadioButton->setChecked(true);
+
+	vbox2 = new QVBoxLayout;
+        vbox2->addWidget(successFailedRadioButton);
+        vbox2->addWidget(successRadioButton);
+        vbox2->addWidget(failedRadioButton);
+	optionButtonGroupBox2->setLayout(vbox2);
+
+	return optionButtonGroupBox2;
+}
+
+QGroupBox *Aureport::createFirstExclusiveGroup()
+{
+        optionButtonGroupBox = new QGroupBox(tr("Attemps"));
+	//second,declear many buttons  
+        authenticationRadioButton = new QRadioButton(tr("authentication attempts"));
+        //authenticationRadioButton->setGeometry( 10, 10, 400, 20 );//-au
+        avcmessagesRadioButton = new QRadioButton(tr("avc messages"));
+        //avcmessagesRadioButton->setGeometry( 10, 30, 400, 40 );//-a
+        configRadioButton = new QRadioButton(tr("config changes"));
+        //configRadioButton->setGeometry( 10, 50, 400, 60 );//-c
+        cryptoRadioButton = new QRadioButton(tr("crypto events"));
+        //cryptoRadioButton->setGeometry( 10, 70, 400, 80 );//-cr
+        eventsRadioButton = new QRadioButton(tr("events"));
+        //eventsRadioButton->setGeometry( 10, 90, 400, 100 );//-e
+        filesRadioButton = new QRadioButton(tr("files"));
+        //filesRadioButton->setGeometry( 10, 110, 400, 120 );//-f
+        hostsRadioButton = new QRadioButton(tr("hosts"));
+        //hostsRadioButton->setGeometry( 10, 130, 400, 140 );//-h
+        loginRadioButton = new QRadioButton(tr("logins"));
+        //loginRadioButton->setGeometry( 10, 150, 400, 160 );//-l
+        modificationsRadioButton = new QRadioButton(tr("account modifications"));
+        //modificationsRadioButton->setGeometry( 10, 170, 400, 180 );//-m
+        macRadioButton = new QRadioButton(tr("Mandatory Access Control(MAC)events"));
+        //macRadioButton->setGeometry( 10, 190, 400, 200 );//-mac
+        pidRadioButton = new QRadioButton(tr("processes"));
+        //pidRadioButton->setGeometry( 10, 210, 400, 220 );//-p
+        responseRadioButton = new QRadioButton(tr("responses to anomaly events"));
+        //responseRadioButton->setGeometry( 10, 230, 400, 240 );//-r
+        syscallRadioButton = new QRadioButton(tr("syscalls"));
+        //syscallRadioButton->setGeometry( 10, 250, 400, 260 );//-s
+        terminalRadioButton = new QRadioButton(tr("terminals"));
+        //terminalRadioButton->setGeometry( 10, 270, 400, 280 );//-tm
+        userRadioButton = new QRadioButton(tr("user"));
+        //userRadioButton->setGeometry( 10, 290, 400, 300 );//-u
+        executableRadioButton = new QRadioButton(tr("executables"));
+        //executableRadioButton->setGeometry( 10, 310, 400, 320 );//-e
+        //optionButtonGroup->resize( 400, 320 );
+
+        authenticationRadioButton->setChecked(true);
+
+	//third,add widget to vboxlayout
+	vbox = new QVBoxLayout;
+        vbox->addWidget(authenticationRadioButton);
+        vbox->addWidget(avcmessagesRadioButton);
+        vbox->addWidget(configRadioButton);
+        vbox->addWidget(cryptoRadioButton);
+        vbox->addWidget(eventsRadioButton);
+        vbox->addWidget(filesRadioButton);
+        vbox->addWidget(hostsRadioButton);
+        vbox->addWidget(loginRadioButton);
+        vbox->addWidget(modificationsRadioButton);
+        vbox->addWidget(macRadioButton);
+	vbox->addWidget(macRadioButton); 
+	vbox->addWidget(pidRadioButton); 
+	vbox->addWidget(responseRadioButton); 
+	vbox->addWidget(syscallRadioButton); 
+	vbox->addWidget(terminalRadioButton); 
+	vbox->addWidget(userRadioButton); 
+	vbox->addWidget(executableRadioButton); 
+	//vbox->addStretch(1); 
+	//fourth,layout vboxlayout to the group box
+	optionButtonGroupBox->setLayout(vbox);
+	
+	return optionButtonGroupBox;
 }
 
 /*signal and slot should have same argument pattern so I had to pass to another slot*/
