@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,17 +25,25 @@
 #include <qlayout.h>
 #include <qcheckbox.h>
 #include <qlabel.h> 
-#include <qbuttongroup.h>
+//added by intrajp
+//#include <q3button.h>
+#include <QButtonGroup>
+#include <QPushButton>
+#include <QGroupBox>
 #include <qradiobutton.h>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+//#include <QGridLayout>
 
 
 class QLayout;
-class QTextEdit;
+class Q3TextEdit;
 class QLineEdit;
 class QPushButton;
 class AureportProcess;
 
 class Aureport: public QDialog 
+//class Aureport: public QWidget
 {
 	Q_OBJECT
 public:
@@ -53,11 +61,15 @@ private:
 	QLabel *starttimeLabel;
 	QLabel *enddayLabel;
 	QLabel *endtimeLabel;
-	QButton *aureportButton;
+	QPushButton *aureportButton;
 	QButtonGroup *optionButtonGroup;
 	QButtonGroup *option2ButtonGroup;
+	QGroupBox *optionButtonGroupBox;
+	QGroupBox *optionButtonGroupBox2;
+	QGroupBox *createFirstExclusiveGroup();
+	QGroupBox *createFirstExclusiveGroup2();
 	QPushButton *closeButton;
-	QTextEdit *textEdit1;
+	Q3TextEdit *textEdit1;
 	QRadioButton *authenticationRadioButton;
 	QRadioButton *avcmessagesRadioButton;
 	QRadioButton *configRadioButton;
@@ -90,15 +102,12 @@ private:
         QLineEdit *enddayEditLineEdit;
         QLineEdit *endtimeEditLineEdit;
 
-	QVBoxLayout *mainLayout;
-	QHBoxLayout *firstLayout;
-	QVBoxLayout *secondLayout;
-	QVBoxLayout *thirdLayout;
-	QHBoxLayout *tirsharyLayout;
-	QHBoxLayout *quadroLayout;
-	QHBoxLayout *fourthLayout;
-	QVBoxLayout *middleLayout;
-	QHBoxLayout *footLayout;
+	QHBoxLayout *mainLayout;
+	QVBoxLayout *leftLayout;
+	QVBoxLayout *vbox;
+	QVBoxLayout *vbox2;
+	QVBoxLayout *rightLayout;
+	//QGridLayout *gridLayout;
 
         QString aureport_str_pp;
         QString aureport_str_pp_str;
@@ -107,7 +116,6 @@ private:
         QString enddayEditLineEdit_str;
         QString endtimeEditLineEdit_str;
 
-
 };
 
 #endif
