@@ -25,9 +25,12 @@
 #include <qlayout.h>
 #include <qdir.h> 
 #include <qlabel.h> 
-#include <qtextedit.h>
-#include <qbuttongroup.h>
+#include <q3textedit.h>
+#include <q3buttongroup.h>
 #include <qradiobutton.h>
+//Added by qt3to4:
+#include <Q3VBoxLayout>
+#include <Q3HBoxLayout>
 
 class AureportProcess: public QDialog 
 {
@@ -43,11 +46,11 @@ private slots:
 public:
 private:
 	QPushButton *closeButton;
-	QTextEdit *textEdit1;
+	Q3TextEdit *textEdit1;
 
-	QVBoxLayout *mainLayout;
-	QVBoxLayout *upperLayout;
-	QHBoxLayout *footLayout;
+	Q3VBoxLayout *mainLayout;
+	Q3VBoxLayout *upperLayout;
+	Q3HBoxLayout *footLayout;
 
         QDir dir;
         QString path;
