@@ -66,6 +66,7 @@ class SemanageCoreFcontextProcess;
 class SemanageCorePortProcess;
 class SemanageCoreTranslationProcess;
 class SemanageCoreBooleanProcess;
+class SemanageCorePermissiveProcess;
 class AutoRelabel;
 class Policygeneration;
 class Aureport;
@@ -119,6 +120,7 @@ private slots:
 	void semanage_core_port_process();
 	void semanage_core_translation_process();
 	void semanage_core_boolean_process();
+	void semanage_core_permissive_process();
 	void autorelabel_process();
 	void policygeneration_process();
 	void aureport();
@@ -195,6 +197,7 @@ private:
 	QAction *semanage_core_port_processAct;
 	QAction *semanage_core_translation_processAct;
 	QAction *semanage_core_boolean_processAct;
+	QAction *semanage_core_permissive_processAct;
 	QAction *autorelabel_processAct;
 	QAction *policygeneration_processAct;
 	QAction *aureportAct;
@@ -227,6 +230,7 @@ private:
 	SemanageCorePortProcess *semanage_core_port_process_o;
 	SemanageCoreTranslationProcess *semanage_core_translation_process_o;
 	SemanageCoreBooleanProcess *semanage_core_boolean_process_o;
+	SemanageCorePermissiveProcess *semanage_core_permissive_process_o;
 	AutoRelabel *autorelabel_process_o;
 	Policygeneration *policygeneration_process_o;
 	Aureport *aureport_o;
