@@ -258,6 +258,57 @@
         <translation type="unfinished">閉じる</translation>
     </message>
 </context>
+<context>
+    <name>Downloader</name>
+    <message>
+        <source>Download fedora</source>
+        <translation type="unfinished">Fedora ダウンロード</translation>
+    </message>
+    <message>
+        <source>us ftp site (mirrors.kernel.org)</source>
+        <translation type="unfinished">アメリカのサイト(mirrors.kernel.org)</translation>
+    </message>
+    <message>
+        <source>jp ftp site (ftp.riken.jp)</source>
+        <translation type="unfinished">日本のサイト(ftp.riken.jp)</translation>
+    </message>
+    <message>
+        <source>version 7</source>
+        <translation type="unfinished">バージョン7</translation>
+    </message>
+    <message>
+        <source>version 8</source>
+        <translation type="unfinished">バージョン8</translation>
+    </message>
+    <message>
+        <source>version 9</source>
+        <translation type="unfinished">バージョン9</translation>
+    </message>
+    <message>
+        <source>Download Fedora</source>
+        <translation type="unfinished">Fedora ダウンロード</translation>
+    </message>
+    <message>
+        <source>close</source>
+        <translation type="unfinished">閉じる</translation>
+    </message>
+    <message>
+        <source>Downloader Fedora</source>
+        <translation type="unfinished">Fedora ダウンローダ</translation>
+    </message>
+    <message>
+        <source>Downloading Fedora in your home directory.</source>
+        <translation type="unfinished">Fedoraをホームディレクトリにダウンロード中</translation>
+    </message>
+    <message>
+        <source>Downloaded files are in your home directory.</source>
+        <translation type="unfinished">Fedoraをホームディレクトリにダウンロードしました。</translation>
+    </message>
+    <message>
+        <source>Downloader Fedora process had an error</source>
+        <translation type="unfinished">エラーです</translation>
+    </message>
+</context>
 <context>
     <name>Editor</name>
     <message>
@@ -994,7 +1045,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>segatex-6.20</source>
-        <translation type="unfinished">segatexバージョン6.20</translation>
+        <translation type="obsolete">segatexバージョン6.20</translation>
     </message>
     <message>
         <source>&amp;restorecon</source>
@@ -1006,10 +1057,30 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
-        <translation type="unfinished">&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+        <translation type="obsolete">&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
     </message>
     <message>
-        <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch. You can restorecon.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
+        <source>segatex-6.40</source>
+        <translation type="unfinished">segatexバージョン6.40</translation>
+    </message>
+    <message>
+        <source>&amp;download Fedora</source>
+        <translation type="unfinished">Fedora ダウンロード</translation>
+    </message>
+    <message>
+        <source>download Fedora</source>
+        <translation type="unfinished">Fedora ダウンロード</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation type="unfinished">ダウンロード</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-6.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="unfinished">&lt;h2&gt;segatex-6.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch. You can restorecon. You can add/delete Linux user. You can ftp download.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1094,7 +1165,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>segatex alert</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">segatex  アラート</translation>
     </message>
     <message>
         <source>No path given.
@@ -1265,7 +1336,7 @@ Try again !</source>
     </message>
     <message>
         <source>audit2allow process had an error !</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">エラーです</translation>
     </message>
 </context>
 <context>
