@@ -26,14 +26,17 @@
 #include <qdir.h> 
 //#include <qvaluevector.h> 
 #include <qlabel.h> 
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3VBoxLayout>
+#include <Q3HBoxLayout>
 
 
 class QLayout;
-class QTextEdit;
+class Q3TextEdit;
 class QLineEdit;
 class QPushButton;
-class QProcess;
+class Q3Process;
 
 class SemanageCoreProcess: public QDialog 
 {
@@ -69,18 +72,18 @@ private:
 	QPushButton *updateButton;
 	QPushButton *removeButton;
 	QPushButton *closeButton;
-	QTextEdit *textEdit1;
-	QTextEdit *textEdit2;
-	QTextEdit *textEdit3;
-	QProcess *process;
+	Q3TextEdit *textEdit1;
+	Q3TextEdit *textEdit2;
+	Q3TextEdit *textEdit3;
+	Q3Process *process;
 
-	QVBoxLayout *mainLayout;
-	QVBoxLayout *upperLayout;
-	QVBoxLayout *underLayout;
-	QHBoxLayout *leftLayout;
+	Q3VBoxLayout *mainLayout;
+	Q3VBoxLayout *upperLayout;
+	Q3VBoxLayout *underLayout;
+	Q3HBoxLayout *leftLayout;
 	//QHBoxLayout *middleLayout;
-	QHBoxLayout *rightLayout;
-	QHBoxLayout *footLayout;
+	Q3HBoxLayout *rightLayout;
+	Q3HBoxLayout *footLayout;
 
         QDir dir;
         QString path;
